==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mcs/class/System/System.Threading/SemaphoreFullException.cs <==
//
// System.Threading.SemaphoreFullException.cs
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Runtime.InteropServices;
using System.Runtime.Serialization;

namespace System.Threading {

	[ComVisible (false)]
	[Serializable]
	public class SemaphoreFullException : SystemException {

		public SemaphoreFullException ()
			: base (Locale.GetText ("Exceeding maximum."))
		{
		}

		public SemaphoreFullException (string message)
			: base (message)
		{
		}

		public SemaphoreFullException (string message, Exception innerException)
			: base (message, innerException)
		{
		}

		protected SemaphoreFullException (SerializationInfo info, StreamingContext context)
			: base (info, context)
		{
		}
	}
}

#endif

==> mono_3.2.8+dfsg.orig.tar.gz: mono-3.2.8+dfsg/mcs/class/System/System.Threading/SemaphoreFullException.cs <==
//
// System.Threading.SemaphoreFullException.cs
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if (!NET_4_0 && !INSIDE_CORLIB) || (NET_4_0 && INSIDE_CORLIB)

using System.Runtime.InteropServices;
using System.Runtime.Serialization;
using System.Runtime.CompilerServices;

namespace System.Threading {

#if NET_4_0 && INSIDE_CORLIB
	[TypeForwardedFrom (Consts.AssemblySystem_2_0)]
#endif
	[ComVisible (false)]
	[Serializable]
	public class SemaphoreFullException : SystemException {

		public SemaphoreFullException ()
			: base (Locale.GetText ("Exceeding maximum."))
		{
		}

		public SemaphoreFullException (string message)
			: base (message)
		{
		}

		public SemaphoreFullException (string message, Exception innerException)
			: base (message, innerException)
		{
		}

		protected SemaphoreFullException (SerializationInfo info, StreamingContext context)
			: base (info, context)
		{
		}
	}

}
#elif NET_4_0 && !INSIDE_CORLIB
using System.Runtime.CompilerServices;
using System.Threading;

[assembly: TypeForwardedTo (typeof (SemaphoreFullException))]
#endif
